@@ -110,6 +110,7 @@ static Panel* panel_allocate(void)
     p->fontsize = 10;
     p->spacing = 0;
     p->icon_size = PANEL_ICON_SIZE;
+    p->icon_theme = gtk_icon_theme_get_default();
     return p;
 }
 
@@ -421,7 +422,7 @@ void panel_determine_background_pixmap(Panel * p, GtkWidget * widget, GdkWindow
         }
         pixmap = fb_bg_get_xroot_pix_for_win(p->bg, widget);
         if ((pixmap != NULL) && (pixmap != GDK_NO_BG) && (p->alpha != 0))
-            fb_bg_composite(pixmap, widget->style->black_gc, p->tintcolor, p->alpha);
+            fb_bg_composite(pixmap, &p->gtintcolor, p->alpha);
     }
 
     if (pixmap != NULL)
@@ -695,7 +696,23 @@ static void panel_popupmenu_about( GtkMenuItem* item, Panel* panel )
     panel_apply_icon(GTK_WINDOW(about));
     gtk_about_dialog_set_version(GTK_ABOUT_DIALOG(about), VERSION);
     gtk_about_dialog_set_name(GTK_ABOUT_DIALOG(about), _("LXPanel"));
-    gtk_about_dialog_set_logo(GTK_ABOUT_DIALOG(about), gdk_pixbuf_new_from_file(PACKAGE_DATA_DIR "/lxpanel/images/my-computer.png", NULL));
+
+    if(gtk_icon_theme_has_icon(panel->icon_theme, "video-display"))
+    {
+         gtk_about_dialog_set_logo( GTK_ABOUT_DIALOG(about),
+                                    gtk_icon_theme_load_icon(panel->icon_theme, "video-display", 48, 0, NULL));
+    }
+    else if (gtk_icon_theme_has_icon(panel->icon_theme, "start-here"))
+    {
+         gtk_about_dialog_set_logo( GTK_ABOUT_DIALOG(about),
+                                    gtk_icon_theme_load_icon(panel->icon_theme, "start-here", 48, 0, NULL));
+    }
+    else 
+    {
+        gtk_about_dialog_set_logo(  GTK_ABOUT_DIALOG(about),
+                                    gdk_pixbuf_new_from_file(PACKAGE_DATA_DIR "/lxpanel/images/my-computer.png", NULL));
+    }
+
     gtk_about_dialog_set_copyright(GTK_ABOUT_DIALOG(about), _("Copyright (C) 2008-2011"));
     gtk_about_dialog_set_comments(GTK_ABOUT_DIALOG(about), _( "Desktop panel for LXDE project"));
     gtk_about_dialog_set_license(GTK_ABOUT_DIALOG(about), "This program is free software; you can redistribute it and/or\nmodify it under the terms of the GNU General Public License\nas published by the Free Software Foundation; either version 2\nof the License, or (at your option) any later version.\n\nThis program is distributed in the hope that it will be useful,\nbut WITHOUT ANY WARRANTY; without even the implied warranty of\nMERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the\nGNU General Public License for more details.\n\nYou should have received a copy of the GNU General Public License\nalong with this program; if not, write to the Free Software\nFoundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.");
@@ -708,7 +725,21 @@ static void panel_popupmenu_about( GtkMenuItem* item, Panel* panel )
 
 void panel_apply_icon( GtkWindow *w )
 {
-    gtk_window_set_icon_from_file(w, PACKAGE_DATA_DIR "/lxpanel/images/my-computer.png", NULL);
+	GdkPixbuf* window_icon;
+	
+	if(gtk_icon_theme_has_icon(gtk_icon_theme_get_default(), "video-display"))
+    {
+		window_icon = gtk_icon_theme_load_icon(gtk_icon_theme_get_default(), "video-display", 24, 0, NULL);
+	}
+	else if(gtk_icon_theme_has_icon(gtk_icon_theme_get_default(), "start-here"))
+    {
+		window_icon = gtk_icon_theme_load_icon(gtk_icon_theme_get_default(), "start-here", 24, 0, NULL);
+	}
+    else
+    {
+		window_icon = gdk_pixbuf_new_from_file(PACKAGE_DATA_DIR "/lxpanel/images/my-computer.png", NULL);
+	}
+    gtk_window_set_icon(w, window_icon);
 }
 
 GtkMenu* lxpanel_get_panel_menu( Panel* panel, Plugin* plugin, gboolean use_sub_menu )
@@ -927,9 +958,9 @@ void panel_image_set_from_file(Panel * p, GtkWidget * image, const char * file)
 /* Set an image from a icon theme with scaling to the panel icon size. */
 gboolean panel_image_set_icon_theme(Panel * p, GtkWidget * image, const gchar * icon)
 {
-    if (gtk_icon_theme_has_icon(gtk_icon_theme_get_default(), icon))
+    if (gtk_icon_theme_has_icon(p->icon_theme, icon))
     {
-        GdkPixbuf * pixbuf = gtk_icon_theme_load_icon(gtk_icon_theme_get_default(), icon, p->icon_size, 0, NULL);
+        GdkPixbuf * pixbuf = gtk_icon_theme_load_icon(p->icon_theme, icon, p->icon_size, 0, NULL);
         gtk_image_set_from_pixbuf(GTK_IMAGE(image), pixbuf);
         g_object_unref(pixbuf);
         return TRUE;
@@ -1061,7 +1092,8 @@ void panel_adjust_geometry_terminology(Panel * p)
 }
 
 /* Draw text into a label, with the user preference color and optionally bold. */
-void panel_draw_label_text(Panel * p, GtkWidget * label, char * text, gboolean bold, gboolean custom_color)
+void panel_draw_label_text(Panel * p, GtkWidget * label, char * text, gboolean bold,
+        float custom_size_factor, gboolean custom_color)
 {
     if (text == NULL)
     {
@@ -1084,6 +1116,7 @@ void panel_draw_label_text(Panel * p, GtkWidget * label, char * text, gboolean b
         	else
         		font_desc = 12;
         }
+        font_desc *= custom_size_factor;
 
         /* Check the string for characters that need to be escaped.
          * If any are found, create the properly escaped string and use it instead. */
@@ -1252,6 +1285,10 @@ panel_parse_global(Panel *p, char **fp)
                     p->background_file = g_strdup( s.t[1] );
                 } else if (!g_ascii_strcasecmp(s.t[0], "IconSize")) {
                     p->icon_size = atoi(s.t[1]);
+                } else if (!g_ascii_strcasecmp(s.t[0], "LogLevel")) {
+                    configured_log_level = atoi(s.t[1]);
+                    if (!log_level_set_on_commandline)
+                        log_level = configured_log_level;
                 } else {
                     ERR( "lxpanel: %s - unknown var in Global section\n", s.t[0]);
                 }
@@ -1601,6 +1638,7 @@ int main(int argc, char *argv[], char *env[])
 
 	g_thread_init(NULL);
 	gdk_threads_init();
+	gdk_threads_enter();
 
     gtk_init(&argc, &argv);
 
@@ -1633,6 +1671,7 @@ int main(int argc, char *argv[], char *env[])
                 exit(1);
             } else {
                 log_level = atoi(argv[i]);
+                log_level_set_on_commandline = true;
             }
         } else if (!strcmp(argv[i], "--configure") || !strcmp(argv[i], "-C")) {
             config = 1;
@@ -1659,8 +1698,7 @@ int main(int argc, char *argv[], char *env[])
     }
 
     /* Add our own icons to the search path of icon theme */
-    gtk_icon_theme_append_search_path( gtk_icon_theme_get_default(),
-                                       PACKAGE_DATA_DIR "/lxpanel/images" );
+    gtk_icon_theme_append_search_path( gtk_icon_theme_get_default(), PACKAGE_DATA_DIR "/lxpanel/images" );
 
     fbev = fb_ev_new();
     win_grp = gtk_window_group_new();
@@ -1699,6 +1737,8 @@ restart:
     if( is_restarting )
         goto restart;
 
+    gdk_threads_leave();
+
     g_object_unref(win_grp);
     g_object_unref(fbev);
 
