@@ -211,7 +211,7 @@ static gboolean dclock_update_display(DClockPlugin * dc)
         gchar * utf8 = g_locale_to_utf8(((newlines_converted != NULL) ? newlines_converted : clock_value), -1, NULL, NULL, NULL);
         if (utf8 != NULL)
         {
-            panel_draw_label_text(dc->plugin->panel, dc->clock_label, utf8, dc->bold, TRUE);
+            panel_draw_label_text(dc->plugin->panel, dc->clock_label, utf8, dc->bold, 1, TRUE);
             g_free(utf8);
         }
         g_free(newlines_converted);
@@ -347,9 +347,9 @@ static int dclock_constructor(Plugin * p, char ** fp)
 
     /* Initialize the clock display. */
     if (dc->clock_format == NULL)
-        dc->clock_format = g_strdup(DEFAULT_CLOCK_FORMAT);
+        dc->clock_format = g_strdup(_(DEFAULT_CLOCK_FORMAT));
     if (dc->tooltip_format == NULL)
-        dc->tooltip_format = g_strdup(DEFAULT_TIP_FORMAT);
+        dc->tooltip_format = g_strdup(_(DEFAULT_TIP_FORMAT));
     dclock_apply_configuration(p);
 
     /* Show the widget and return. */
@@ -387,7 +387,9 @@ static void dclock_apply_configuration(Plugin * p)
     /* Set up the icon or the label as the displayable widget. */
     if (dc->icon_only)
     {
-        panel_image_set_from_file(p->panel, dc->clock_icon, PACKAGE_DATA_DIR "/lxpanel/images/clock.png");
+		if(panel_image_set_icon_theme(p->panel, dc->clock_icon, "clock") != FALSE) {
+			panel_image_set_from_file(p->panel, dc->clock_icon, PACKAGE_DATA_DIR "/lxpanel/images/clock.png");
+		}
         gtk_widget_show(dc->clock_icon);
         gtk_widget_hide(dc->clock_label);
     }
