@@ -126,7 +126,6 @@ static gchar *taskbar_rc = "style 'taskbar-style'\n"
 
 #define DRAG_ACTIVE_DELAY    1000
 #define TASK_WIDTH_MAX       200
-#define TASK_PADDING         4
 #define ALL_WORKSPACES       0xFFFFFFFF		/* 64-bit clean */
 #define ICON_ONLY_EXTRA      6		/* Amount needed to have button lay out symmetrically */
 #define ICON_BUTTON_TRIM 4		/* Amount needed to have button remain on panel */
@@ -301,7 +300,7 @@ static void task_draw_label(Task * tk)
 	{
         char * label = g_strdup_printf("(%d) %s", tc->visible_count, tc->visible_name);
         gtk_widget_set_tooltip_text(tk->button, label);
-        panel_draw_label_text(tk->tb->plug->panel, tk->label, label, bold_style, tk->tb->flat_button);
+        panel_draw_label_text(tk->tb->plug->panel, tk->label, label, bold_style, 1, tk->tb->flat_button);
         g_free(label);
 	}
     else
@@ -309,7 +308,7 @@ static void task_draw_label(Task * tk)
         char * name = tk->iconified ? tk->name_iconified : tk->name;
         if (tk->tb->tooltips)
             gtk_widget_set_tooltip_text(tk->button, name);
-        panel_draw_label_text(tk->tb->plug->panel, tk->label, name, bold_style, tk->tb->flat_button);
+        panel_draw_label_text(tk->tb->plug->panel, tk->label, name, bold_style, 1, tk->tb->flat_button);
     }
 }
 
@@ -554,8 +553,10 @@ static void task_delete(TaskbarPlugin * tb, Task * tk, gboolean unlink)
         tb->focused = NULL;
 
     /* If there is an urgency timeout, remove it. */
-    if (tk->flash_timeout != 0)
+    if (tk->flash_timeout != 0) {
         g_source_remove(tk->flash_timeout);
+        tk->flash_timeout = 0;
+    }
 
     /* Deallocate structures. */
     icon_grid_remove(tb->icon_grid, tk->button);
